@@ -1,3 +1,4 @@
+from lime_python.utils.documentsType import GetDocumentByMediaType
 from lime_python.utils.header import Header
 from lime_python.utils.reason import Reason
 from lime_python.utils.reasonCode import ReasonCode
@@ -5,3 +6,5 @@ from lime_python.utils.scope import Scope
 from lime_python.utils.stringUtils import StringUtils
 from lime_python.utils.limeException import LimeException
 from lime_python.utils.paymentItem import PaymentItem
+from lime_python.utils.paymentMethod import PaymentMethod
+from lime_python.utils.baseType import GetBaseByClassName
