@@ -1,3 +1,4 @@
+from lime_python.utils.documentsType import GetDocumentByMediaType
 from lime_python.base.document import Document
 
 
@@ -37,3 +38,15 @@ class Header:
             'type': str(self.GetMediaType()),
             'value': self.GetValueJson()
         }
+
+    def FromJson(inJson):
+        if isinstance(inJson, str):
+            inJson = json.loads(inJson)
+        try:
+            return Header(
+                GetDocumentByMediaType(
+                    inJson['type']
+                ).FromJson(inJson['value'])
+            )
+        except KeyError:
+            raise ValueError('The given json is not a InputDocument')
